summaryrefslogtreecommitdiffstats
path: root/kjsembed/qtbindings/qcanvasellipse_imp.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kjsembed/qtbindings/qcanvasellipse_imp.cpp')
-rw-r--r--kjsembed/qtbindings/qcanvasellipse_imp.cpp98
1 files changed, 49 insertions, 49 deletions
diff --git a/kjsembed/qtbindings/qcanvasellipse_imp.cpp b/kjsembed/qtbindings/qcanvasellipse_imp.cpp
index 6d9311e7..deab7241 100644
--- a/kjsembed/qtbindings/qcanvasellipse_imp.cpp
+++ b/kjsembed/qtbindings/qcanvasellipse_imp.cpp
@@ -23,19 +23,19 @@
*/
namespace KJSEmbed {
-QCanvasEllipseImp::QCanvasEllipseImp( KJS::ExecState *exec, int mid, bool constructor )
+TTQCanvasEllipseImp::TQCanvasEllipseImp( KJS::ExecState *exec, int mid, bool constructor )
: JSProxyImp(exec), id(mid), cons(constructor)
{
}
-QCanvasEllipseImp::~QCanvasEllipseImp()
+TTQCanvasEllipseImp::~TQCanvasEllipseImp()
{
}
/**
* Adds bindings for static methods and enum constants to the specified Object.
*/
-void QCanvasEllipseImp::addStaticBindings( KJS::ExecState *exec, KJS::Object &object )
+void TQCanvasEllipseImp::addStaticBindings( KJS::ExecState *exec, KJS::Object &object )
{
JSProxy::MethodTable methods[] = {
@@ -43,11 +43,11 @@ void QCanvasEllipseImp::addStaticBindings( KJS::ExecState *exec, KJS::Object &ob
};
int idx = 0;
- TQCString lastName;
+ TTQCString lastName;
while( methods[idx].name ) {
if ( lastName != methods[idx].name ) {
- QCanvasEllipseImp *meth = new QCanvasEllipseImp( exec, methods[idx].id );
+ TQCanvasEllipseImp *meth = new TQCanvasEllipseImp( exec, methods[idx].id );
object.put( exec , methods[idx].name, KJS::Object(meth) );
lastName = methods[idx].name;
}
@@ -60,7 +60,7 @@ void QCanvasEllipseImp::addStaticBindings( KJS::ExecState *exec, KJS::Object &ob
/**
* Adds bindings for instance methods to the specified Object.
*/
-void QCanvasEllipseImp::addBindings( KJS::ExecState *exec, KJS::Object &object )
+void TQCanvasEllipseImp::addBindings( KJS::ExecState *exec, KJS::Object &object )
{
JSProxy::MethodTable methods[] = {
@@ -77,11 +77,11 @@ void QCanvasEllipseImp::addBindings( KJS::ExecState *exec, KJS::Object &object )
};
int idx = 0;
- TQCString lastName;
+ TTQCString lastName;
while( methods[idx].name ) {
if ( lastName != methods[idx].name ) {
- QCanvasEllipseImp *meth = new QCanvasEllipseImp( exec, methods[idx].id );
+ TQCanvasEllipseImp *meth = new TQCanvasEllipseImp( exec, methods[idx].id );
object.put( exec , methods[idx].name, KJS::Object(meth) );
lastName = methods[idx].name;
}
@@ -90,89 +90,89 @@ void QCanvasEllipseImp::addBindings( KJS::ExecState *exec, KJS::Object &object )
}
/**
* Extract a TQCanvasEllipse pointer from an Object.
*/
-TQCanvasEllipse *QCanvasEllipseImp::toQCanvasEllipse( KJS::Object &self )
+TTQCanvasEllipse *TQCanvasEllipseImp::toTQCanvasEllipse( KJS::Object &self )
{
JSObjectProxy *ob = JSProxy::toObjectProxy( self.imp() );
if ( ob ) {
- TQObject *obj = ob->object();
+ TTQObject *obj = ob->object();
if ( obj )
- return dynamic_cast<TQCanvasEllipse *>( obj );
+ return dynamic_cast<TTQCanvasEllipse *>( obj );
}
JSOpaqueProxy *op = JSProxy::toOpaqueProxy( self.imp() );
if ( !op )
return 0;
- if ( op->typeName() != "TQCanvasEllipse" )
+ if ( op->typeName() != "TTQCanvasEllipse" )
return 0;
- return op->toNative<TQCanvasEllipse>();
+ return op->toNative<TTQCanvasEllipse>();
}
/**
* Select and invoke the correct constructor.
*/
-KJS::Object QCanvasEllipseImp::construct( KJS::ExecState *exec, const KJS::List &args )
+KJS::Object TQCanvasEllipseImp::construct( KJS::ExecState *exec, const KJS::List &args )
{
switch( id ) {
case Constructor_QCanvasEllipse_1:
- return QCanvasEllipse_1( exec, args );
+ return TQCanvasEllipse_1( exec, args );
break;
case Constructor_QCanvasEllipse_2:
- return QCanvasEllipse_2( exec, args );
+ return TQCanvasEllipse_2( exec, args );
break;
case Constructor_QCanvasEllipse_3:
- return QCanvasEllipse_3( exec, args );
+ return TQCanvasEllipse_3( exec, args );
break;
default:
break;
}
- TQString msg = i18n("QCanvasEllipseCons has no constructor with id '%1'.").arg(id);
+ TTQString msg = i18n("TQCanvasEllipseCons has no constructor with id '%1'.").arg(id);
return throwError(exec, msg,KJS::ReferenceError);
}
-KJS::Object QCanvasEllipseImp::QCanvasEllipse_1( KJS::ExecState *exec, const KJS::List &args )
+KJS::Object TQCanvasEllipseImp::TQCanvasEllipse_1( KJS::ExecState *exec, const KJS::List &args )
{
// Unsupported parameter TQCanvas *
return KJS::Object();
- TQCanvas * arg0; // Dummy
+ TTQCanvas * arg0; // Dummy
- // We should now create an instance of the TQCanvasEllipse object
+ // We should now create an instance of the TTQCanvasEllipse object
- TQCanvasEllipse *ret = new TQCanvasEllipse(
+ TTQCanvasEllipse *ret = new TTQCanvasEllipse(
arg0 );
}
-KJS::Object QCanvasEllipseImp::QCanvasEllipse_2( KJS::ExecState *exec, const KJS::List &args )
+KJS::Object TQCanvasEllipseImp::TQCanvasEllipse_2( KJS::ExecState *exec, const KJS::List &args )
{
int arg0 = extractInt(exec, args, 0);
int arg1 = extractInt(exec, args, 1);
// Unsupported parameter TQCanvas *
return KJS::Object();
- TQCanvas * arg2; // Dummy
+ TTQCanvas * arg2; // Dummy
- // We should now create an instance of the TQCanvasEllipse object
+ // We should now create an instance of the TTQCanvasEllipse object
- TQCanvasEllipse *ret = new TQCanvasEllipse(
+ TTQCanvasEllipse *ret = new TTQCanvasEllipse(
arg0,
arg1,
@@ -181,7 +181,7 @@ KJS::Object QCanvasEllipseImp::QCanvasEllipse_2( KJS::ExecState *exec, const KJS
}
-KJS::Object QCanvasEllipseImp::QCanvasEllipse_3( KJS::ExecState *exec, const KJS::List &args )
+KJS::Object TQCanvasEllipseImp::TQCanvasEllipse_3( KJS::ExecState *exec, const KJS::List &args )
{
int arg0 = extractInt(exec, args, 0);
@@ -192,15 +192,15 @@ KJS::Object QCanvasEllipseImp::QCanvasEllipse_3( KJS::ExecState *exec, const KJS
int arg3 = extractInt(exec, args, 3);
// Unsupported parameter TQCanvas *
return KJS::Object();
- TQCanvas * arg4; // Dummy
+ TTQCanvas * arg4; // Dummy
- // We should now create an instance of the TQCanvasEllipse object
+ // We should now create an instance of the TTQCanvasEllipse object
- TQCanvasEllipse *ret = new TQCanvasEllipse(
+ TTQCanvasEllipse *ret = new TTQCanvasEllipse(
arg0,
arg1,
@@ -211,9 +211,9 @@ KJS::Object QCanvasEllipseImp::QCanvasEllipse_3( KJS::ExecState *exec, const KJS
}
-KJS::Value QCanvasEllipseImp::call( KJS::ExecState *exec, KJS::Object &self, const KJS::List &args )
+KJS::Value TQCanvasEllipseImp::call( KJS::ExecState *exec, KJS::Object &self, const KJS::List &args )
{
- instance = QCanvasEllipseImp::toQCanvasEllipse( self );
+ instance = TQCanvasEllipseImp::toTQCanvasEllipse( self );
switch( id ) {
@@ -257,12 +257,12 @@ KJS::Value QCanvasEllipseImp::call( KJS::ExecState *exec, KJS::Object &self, con
break;
}
- TQString msg = i18n( "QCanvasEllipseImp has no method with id '%1'." ).arg( id );
+ TTQString msg = i18n( "TQCanvasEllipseImp has no method with id '%1'." ).arg( id );
return throwError(exec, msg,KJS::ReferenceError);
}
-KJS::Value QCanvasEllipseImp::width_5( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
+KJS::Value TQCanvasEllipseImp::width_5( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
int ret;
@@ -271,7 +271,7 @@ KJS::Value QCanvasEllipseImp::width_5( KJS::ExecState *exec, KJS::Object &obj, c
}
-KJS::Value QCanvasEllipseImp::height_6( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
+KJS::Value TQCanvasEllipseImp::height_6( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
int ret;
@@ -280,7 +280,7 @@ KJS::Value QCanvasEllipseImp::height_6( KJS::ExecState *exec, KJS::Object &obj,
}
-KJS::Value QCanvasEllipseImp::setSize_7( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
+KJS::Value TQCanvasEllipseImp::setSize_7( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
int arg0 = extractInt(exec, args, 0);
@@ -294,7 +294,7 @@ KJS::Value QCanvasEllipseImp::setSize_7( KJS::ExecState *exec, KJS::Object &obj,
}
-KJS::Value QCanvasEllipseImp::setAngles_8( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
+KJS::Value TQCanvasEllipseImp::setAngles_8( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
int arg0 = extractInt(exec, args, 0);
@@ -308,7 +308,7 @@ KJS::Value QCanvasEllipseImp::setAngles_8( KJS::ExecState *exec, KJS::Object &ob
}
-KJS::Value QCanvasEllipseImp::angleStart_9( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
+KJS::Value TQCanvasEllipseImp::angleStart_9( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
int ret;
@@ -317,7 +317,7 @@ KJS::Value QCanvasEllipseImp::angleStart_9( KJS::ExecState *exec, KJS::Object &o
}
-KJS::Value QCanvasEllipseImp::angleLength_10( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
+KJS::Value TQCanvasEllipseImp::angleLength_10( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
int ret;
@@ -326,21 +326,21 @@ KJS::Value QCanvasEllipseImp::angleLength_10( KJS::ExecState *exec, KJS::Object
}
-KJS::Value QCanvasEllipseImp::areaPoints_11( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
+KJS::Value TQCanvasEllipseImp::areaPoints_11( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
instance->areaPoints( );
- return KJS::Value(); // Returns 'QPointArray'
+ return KJS::Value(); // Returns 'TQPointArray'
}
-KJS::Value QCanvasEllipseImp::collidesWith_12( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
+KJS::Value TQCanvasEllipseImp::collidesWith_12( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
// Unsupported parameter const TQCanvasItem *
return KJS::Value();
- const TQCanvasItem * arg0; // Dummy
+ const TTQCanvasItem * arg0; // Dummy
bool ret;
ret = instance->collidesWith(
@@ -349,7 +349,7 @@ KJS::Value QCanvasEllipseImp::collidesWith_12( KJS::ExecState *exec, KJS::Object
}
-KJS::Value QCanvasEllipseImp::rtti_13( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
+KJS::Value TQCanvasEllipseImp::rtti_13( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
int ret;
@@ -90,89 +90,89 @@ void QCanvasEllipseImp::addBindings( KJS::ExecState *exec, KJS::Object &object )
}
/**
- * Extract a TQCanvasEllipse pointer from an Object.
+ * Extract a TTQCanvasEllipse pointer from an Object.
*/
@@ -90,89 +90,89 @@ void QCanvasEllipseImp::addBindings( KJS::ExecState *exec, KJS::Object &object )
{
- // Unsupported parameter TQCanvas *
+ // Unsupported parameter TTQCanvas *
return KJS::Object();
@@ -90,89 +90,89 @@ void QCanvasEllipseImp::addBindings( KJS::ExecState *exec, KJS::Object &object )
int arg0 = extractInt(exec, args, 0);
int arg1 = extractInt(exec, args, 1);
- // Unsupported parameter TQCanvas *
+ // Unsupported parameter TTQCanvas *
return KJS::Object();
@@ -192,15 +192,15 @@ KJS::Object QCanvasEllipseImp::QCanvasEllipse_3( KJS::ExecState *exec, const KJS
int arg3 = extractInt(exec, args, 3);
- // Unsupported parameter TQCanvas *
+ // Unsupported parameter TTQCanvas *
return KJS::Object();
@@ -326,21 +326,21 @@ KJS::Value QCanvasEllipseImp::angleLength_10( KJS::ExecState *exec, KJS::Object
{
- // Unsupported parameter const TQCanvasItem *
+ // Unsupported parameter const TTQCanvasItem *
return KJS::Value();